﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.SqlServer.Dts.Runtime;
using Microsoft.SqlServer.Dts.Tasks.ExecutePackageTask;

namespace ExecutePackage
{
    class Program
    {
        static void Main(string[] args)
        {
            PackageEvents events = new PackageEvents();

            // Create a project
            Project project = Project.CreateProject();

            // Create the Child package
            Package childPackage = new Package();
            childPackage.DesignEvents = events;
            childPackage.Name = "Child";

            // Define a parameter
            var param = childPackage.Parameters.Add("InputFilePath", TypeCode.String);
            param.Required = true;
            param.Value = @"c:\book\chapter19\inputfile.txt";

            // Create a connection manager with an expression that uses the InputFilePath parameter
            var cm = childPackage.Connections.Add("FILE");
            cm.Name = "Input File";
            cm.SetExpression("ConnectionString", "@[$Package::InputFilePath]");

            // add the child package to the project
            project.PackageItems.Add(childPackage, "Child.dtsx");

            // Create the parent package
            Package parentPackage = new Package();
            parentPackage.DesignEvents = events;
            parentPackage.Name = "Parent";

            // Add the parent package to the project
            project.PackageItems.Add(parentPackage, "Parent.dtsx");

            // Add a variable to store the value we'll use in the execute package task binding
            parentPackage.Variables.Add("FilePath", false, "User", @"C:\ParentFilePath.txt");

            // Add the execute package task
            var taskHost = parentPackage.Executables.Add("STOCK:ExecutePackageTask") as TaskHost;
            var execPkgTask = taskHost.InnerObject as ExecutePackageTask;

            // configure the task
            execPkgTask.UseProjectReference = true;
            var assignment = execPkgTask.ParameterAssignments.Add();
            assignment.BindedVariableOrParameterName = "FilePath";  // variable in parent
            assignment.ParameterName = "InputFilePath"; // parameter in child
        }
    }
}
